## Example: toggles

<div class="grid">

```typescript
import React, { Component } from 'react';
import uniqueId from 'lodash/uniqueId';

import Icon from 'components/Icon';

import styled from 'styled-components';
import theme from 'theme';

const TRANSITION_SPEED = '0.25s';

export const StyledContainer = styled.div`
  [type='checkbox'] {
    display: none;

    & + label {
      cursor: pointer;
      display: block;
      width: 56px;
      height: 26px;
      color: ${theme.colours.gray700};
      background-color: ${theme.colours.gray700};
      border-radius: 18px;
      position: relative;
      padding: 2px;
      transition: color ${TRANSITION_SPEED}, background-color ${TRANSITION_SPEED};

      &:hover {
        color: ${theme.colours.gray800};
        background-color: ${theme.colours.gray800};
      }
    }

    &:checked + label {
      color: ${theme.colours.confirmation500};
      background-color: ${theme.colours.confirmation500};

      &:hover {
        color: ${theme.colours.confirmation600};
        background-color: ${theme.colours.confirmation600};
      }
    }
  }
  [disabled] + label {
    opacity: 0.5;
    cursor: not-allowed;
    pointer-events: none;
  }
`;

export const StyledIconContainer = styled.div`
  display: inline-block;
  width: 24px;
  height: 24px;
  position: absolute;
  right: 33px;
  top: 50%;
  transform: translateY(-50%);
  border-radius: 50%;
  background-color: white;
  transition: right ${TRANSITION_SPEED};

  &.active {
    right: 3px;
  }
`;

export const StyledIcon = styled.div`
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translateX(-50%) translateY(-50%);
`;


type Props = {
  active: boolean;
  disabled?: boolean;
  onActivate: () => void;
  onDeactivate: () => void;
  className?: string;
};

type State = {
  active: boolean;
};

export default class Toggle extends Component<Props, State> {
  static defaultProps = {
    active: false,
    disabled: false,
    onActivate: () => {},
    onDeactivate: () => {},
  };

  id = uniqueId('toggle-');

  state = {
    active: this.props.active,
  };

  componentDidUpdate(prevProps: Readonly<Props>, prevState: Readonly<State>) {
    if (prevState.active !== this.state.active) {
      return;
    }
    const { active } = this.props;
    if (prevProps.active !== active && this.state.active !== active) {
      this.setState({ active });
    }
  }

  toggle = () => {
    const newActive = !this.state.active;
    newActive ? this.props.onActivate() : this.props.onDeactivate();
    this.setState({ active: newActive });
  };

  render() {
    const { disabled, className } = this.props;
    const { active } = this.state;
    return (
      <StyledContainer className={className}>
        <input
          id={this.id}
          type="checkbox"
          checked={active}
          disabled={disabled}
          readOnly={true}
          onChange={this.toggle}
          onClick={(e) => e.stopPropagation()}
          aria-label="toggle"
        />
        <label htmlFor={this.id}>
          <StyledIconContainer className={active ? 'active' : undefined}>
            <StyledIcon>{active ? <Icon icon="tick" size={14} /> : <Icon icon="close" size={18} />}</StyledIcon>
          </StyledIconContainer>
        </label>
      </StyledContainer>
    );
  }
}
```

<div>

<div data-react-root="toggle"></div>

* 139 lines of code (+ the Icons, theme, 3 libraries required)
* Manual state management
* Have to import all of this everywhere we use it
* No meaningful labels possible!
* No keyboard navigation
* No Javascript? No component

</div>

</div>