## Example 1: Fixing the toggle

<div class="grid">

```html
<style>
input[type="checkbox"][role="switch"] {
	appearance: none;
	background: lightgray;
	border: 1px solid gray;
	width: 50px;
	height: 20px;
	border-radius: 20px;
	position: relative;
	cursor: pointer;
	
	&::before {
		content: " ";
		width: 14px;
		aspect-ratio: 1;
		background: gray;
		position: absolute;
		left: 2px;
		top: 1px;
		border-radius: 20px;
		border: 1px solid transparent;
		transition:
            left .2s ease-in-out,
            right .2s ease-in-out;
	}
	
	&:checked {
		background: lightgreen;
		
		&::before {
			border-color: gray;
			background-color: white;
			left: calc(100% - 18px);
		}
	}
}
</style>

<input
    type="checkbox"
    role="switch"
    name="activated"
/>
```

<div>
	<label>
		Enable:
		<input
			type="checkbox"
			role="switch"
			name="activated"
		/>
	</label>

* 42 lines of code
* Uses regular HTML markup - 0 javascript needed
* `switch` role tells the browser that this is an on/off rather than a checked/unchecked component
* Easily accessible to screen readers, keyboard users
* Can be used anywhere - all you need is the stylesheet at the top level
* Graceful degradation - if the CSS doesn't load we still get a checkbox
</div>

</div>