## Example 3: Accordions

<div class="grid">

```typescript
import React, { useState } from 'react';
import styled from 'styled-components';
import Icon from '../../../../../components/Icon';
import theme from '../../../../../theme';

type AccordionProps = {
  title: string;
  items: (string | null)[];
};

const Container = styled.div`
  width: 100%;
`;

const AccordionSummary = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  cursor: pointer;
`;

interface ExpandedProps {
  expanded: boolean;
}

export const StyledArrow = styled(Icon).attrs({
  icon: 'dropdownArrow',
  size: 15,
  color: theme.colours.primary500,
})<ExpandedProps>`
  position: relative;
  transform: rotate(${({ expanded }) => (expanded ? '180deg' : '0')});
`;

const Title = styled.span<ExpandedProps>`
  font-weight: ${({ expanded }) => (expanded ? 'bold' : 'normal')};
`;

const ItemList = styled.div`
  display: flex;
  flex-direction: column;
`;

const Accordion = ({ title, items }: AccordionProps) => {
  const [expanded, setExpanded] = useState(false);

  return (
    <Container>
      <AccordionSummary
        onClick={() => {
          setExpanded(!expanded);
        }}
      >
        <Title expanded={expanded}>{title}</Title>
        <StyledArrow expanded={expanded} />
      </AccordionSummary>
      {expanded && (
        <ItemList>
          {items.map((item) => {
            return <div key={item}>{item}</div>;
          })}
        </ItemList>
      )}
    </Container>
  );
};

export default Accordion;
```

<div>

<div data-react-root="accordion"></div>

* 67 lines of code
* Manual state management
* Divs with onClick handlers - unreachable by keyboard, no screen reader support

</div>

</div>